@@ -34,6 +34,7 @@
 
 struct _ArioFilesystemPluginPrivate
 {
+        gchar *menu_file;
         guint ui_merge_id;
         GtkWidget *source;
 };
@@ -50,30 +51,11 @@ static void
 impl_activate (ArioPlugin *plugin,
                ArioShell *shell)
 {
-        GtkUIManager *uimanager;
-        GtkActionGroup *actiongroup;
         ArioFilesystemPlugin *pi = ARIO_FILESYSTEM_PLUGIN (plugin);
-        gchar *file;
 
-        g_object_get (shell,
-                      "ui-manager", &uimanager,
-                      "action-group", &actiongroup,
-                      NULL);
-
-        pi->priv->source = ario_filesystem_new (uimanager,
-                                                actiongroup);
+        pi->priv->source = ario_filesystem_new ();
         g_return_if_fail (IS_ARIO_FILESYSTEM (pi->priv->source));
 
-        file = ario_plugin_find_file ("filesystem-ui.xml");
-        if (file) {
-                pi->priv->ui_merge_id = gtk_ui_manager_add_ui_from_file (uimanager,
-                                                                         file, NULL);
-                g_free (file);
-        }
-
-        g_object_unref (uimanager);
-        g_object_unref (actiongroup);
-
         ario_source_manager_append (ARIO_SOURCE (pi->priv->source));
         ario_source_manager_reorder ();
 }
@@ -82,14 +64,7 @@ static void
 impl_deactivate (ArioPlugin *plugin,
                  ArioShell *shell)
 {
-        GtkUIManager *uimanager;
-
         ArioFilesystemPlugin *pi = ARIO_FILESYSTEM_PLUGIN (plugin);
-
-        g_object_get (shell, "ui-manager", &uimanager, NULL);
-        gtk_ui_manager_remove_ui (uimanager, pi->priv->ui_merge_id);
-        g_object_unref (uimanager);
-
         ario_source_manager_remove (ARIO_SOURCE (pi->priv->source));
 }
 
