@@ -21,11 +21,10 @@
 #include <locale.h>
 #include <libintl.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
+#include <gdk/gdk.h>
 #include <curl/curl.h>
 #include <libxml/parser.h>
 #include <glib/gi18n.h>
-#include <gcrypt.h>
 #include "lib/ario-conf.h"
 #include "preferences/ario-preferences.h"
 #include "shell/ario-shell.h"
@@ -36,33 +35,27 @@
 
 #ifdef WIN32
 #include <windows.h>
-#else
-#include <unique/unique.h>
 #endif
 
-#ifndef WIN32
-static UniqueResponse
-ario_main_on_message_received (G_GNUC_UNUSED UniqueApp *app,
-                               G_GNUC_UNUSED UniqueCommand command,
-                               G_GNUC_UNUSED UniqueMessageData *message,
-                               G_GNUC_UNUSED guint time_,
-                               ArioShell *shell)
+static ArioShell *shell = NULL;
+static gboolean minimized = FALSE;
+
+static void
+activate (GtkApplication *app)
 {
         ario_shell_present (shell);
-        return UNIQUE_RESPONSE_OK;
 }
-#endif
 
 int
 main (int argc, char *argv[])
 {
         ARIO_LOG_FUNCTION_START;
-        ArioShell *shell;
+        GError *error = NULL;
+        gint status = 0;
 
         /* Parse options */
         GOptionContext *context;
         gchar *profile = NULL;
-        gboolean minimized = FALSE;
         const GOptionEntry options []  = {
                 { "minimized", 'm', 0, G_OPTION_ARG_NONE, &minimized, N_("Start minimized window"), NULL },
                 { "profile", 'p', 0, G_OPTION_ARG_STRING, &profile, N_("Start with specific profile"), NULL },
@@ -73,7 +66,10 @@ main (int argc, char *argv[])
         g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
         g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
-        g_option_context_parse (context, &argc, &argv, NULL);
+        if (!g_option_context_parse (context, &argc, &argv, &error)) {
+                g_print ("option parsing failed: %s\n", error->message);
+                exit (1);
+        }
         g_option_context_free (context);
 
         /* Initialisation of configurations engine */
@@ -88,16 +84,6 @@ main (int argc, char *argv[])
                 ARIO_LOG_INFO ("Ario is already running\n");
                 return 0;
         }
-#else
-        UniqueApp *app;
-        app = unique_app_new ("org.Ario", NULL);
-        if (unique_app_is_running (app)) {
-                if (ario_conf_get_boolean (PREF_ONE_INSTANCE, PREF_ONE_INSTANCE_DEFAULT)) {
-                        unique_app_send_message (app, UNIQUE_ACTIVATE, NULL);
-                        g_object_unref (app);
-                        return 0;
-                }
-        }
 #endif
 
         /* Initialisation of translation */
@@ -108,18 +94,8 @@ main (int argc, char *argv[])
         textdomain (GETTEXT_PACKAGE);
 #endif
 
-        /* Initialisation of threads */
-        if (!g_thread_supported ()) g_thread_init (NULL);
-
-        /* Initialisation of GTK */
-        setlocale (LC_ALL, "");
-        gtk_init (&argc, &argv);
-
-        /* Initialisation of libgcrypt */
-        gcry_check_version (NULL);
-
         /* Register Ario icons */
-        ario_util_init_stock_icons ();
+        ario_util_init_icons ();
 
         /* Initialisation of Curl */
         curl_global_init (CURL_GLOBAL_WIN32);
@@ -130,18 +106,24 @@ main (int argc, char *argv[])
                 ario_profiles_set_current_by_name (profile);
 #endif
         /* Creates Ario main window */
-        shell = ario_shell_new ();
+        GtkApplication *app;
+        app = gtk_application_new ("org.Ario", G_APPLICATION_FLAGS_NONE);
+        g_application_register (G_APPLICATION (app), NULL, NULL);
+        if (g_application_get_is_remote (G_APPLICATION (app))) {
+                g_application_activate (G_APPLICATION (app));
+                g_object_unref (app);
+                return 0;
+        }
+        shell = ario_shell_new (app);
+        gtk_window_set_application (GTK_WINDOW (shell), app);
         ario_shell_construct (shell, minimized);
+        g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
 
-#ifndef WIN32
-        unique_app_watch_window (app, GTK_WINDOW (shell));
-        g_signal_connect (app, "message-received", G_CALLBACK (ario_main_on_message_received), shell);
-#endif
         /* Initialisation of plugins engine */
         ario_plugins_engine_init (shell);
 
         /* Starts GTK main loop */
-        gtk_main ();
+        status = g_application_run (G_APPLICATION (app), argc, argv);
 
         /* Shutdown main window */
         ario_shell_shutdown (shell);
@@ -160,6 +142,6 @@ main (int argc, char *argv[])
         /* Clean libxml stuff */
         xmlCleanupParser ();
 
-        return 0;
+        return status;
 }
 
