@@ -27,7 +27,6 @@
 #include <string.h>
 #include <curl/curl.h>
 #include <glib/gi18n.h>
-#include <gcrypt.h>
 #ifdef WIN32
 #include <windows.h>
 #endif
@@ -191,51 +190,14 @@ ario_util_format_title (ArioServerSong *server_song)
         return res;
 }
 
-static GtkIconFactory *factory = NULL;
-
 void
-ario_util_add_stock_icons (const char *stock_id,
-                           const char *filename)
+ario_util_init_icons (void)
 {
         ARIO_LOG_FUNCTION_START;
 
-        static int icon_size = 0;
-        GdkPixbuf *pb;
-        GtkIconSet *set;
-
-        if (!icon_size)
-                gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &icon_size, NULL);
-
-        pb = gdk_pixbuf_new_from_file (filename,
-                                       NULL);
-        set = gtk_icon_set_new_from_pixbuf (pb);
-        gtk_icon_factory_add (factory, stock_id, set);
-        g_object_unref (pb);
-}
-
-void
-ario_util_init_stock_icons (void)
-{
-        ARIO_LOG_FUNCTION_START;
-
-        factory = gtk_icon_factory_new ();
-
-        ario_util_add_stock_icons ("ario", PIXMAP_PATH "ario.png");
-        ario_util_add_stock_icons ("ario-play", PIXMAP_PATH "ario-play.png");
-        ario_util_add_stock_icons ("ario-pause", PIXMAP_PATH "ario-pause.png");
-        ario_util_add_stock_icons ("repeat", PIXMAP_PATH "repeat.png");
-        ario_util_add_stock_icons ("random", PIXMAP_PATH "shuffle.png");
-        ario_util_add_stock_icons ("pl-below", PIXMAP_PATH "pl-below.png");
-        ario_util_add_stock_icons ("pl-right", PIXMAP_PATH "pl-right.png");
-        ario_util_add_stock_icons ("pl-inside", PIXMAP_PATH "pl-inside.png");
-
-        gtk_icon_factory_add_default (factory);
-}
-
-gboolean
-ario_util_has_stock_icons (const char *stock_id)
-{
-        return (gtk_icon_factory_lookup_default (stock_id) != NULL);
+        GtkIconTheme *icon_theme;
+        icon_theme = gtk_icon_theme_get_default ();
+        gtk_icon_theme_append_search_path (icon_theme, PIXMAP_PATH);
 }
 
 const char *
@@ -530,43 +492,9 @@ char *
 ario_util_format_keyword_for_lastfm (const char *keyword)
 {
         ARIO_LOG_FUNCTION_START;
-        int i;
-        gchar *ret;
-
-        /* List of modifications done on the keuword used for the search */
-        const gchar *to_remove[] = {"cd 1", "cd 2", "cd 3", "cd 4", "cd 5",
-                "cd1", "cd2", "cd3", "cd4", "cd5",
-                "disc", "disk", "disque", "remastered", NULL};
 
         /* Escape string */
-        ret = g_uri_escape_string (keyword, NULL, FALSE);
-
-        /* We remove some useless words to make more accurate requests */
-        for (i = 0; to_remove[i]; ++i) {
-                ario_util_string_replace (&ret, to_remove[i], " ");
-        }
-
-        return ret;
-}
-
-gchar *
-ario_util_md5 (const char *string)
-{
-        ARIO_LOG_FUNCTION_START;
-        guchar md5pword[16];
-        gchar md5_response[33] = {0};
-        int j;
-
-        gcry_md_hash_buffer (GCRY_MD_MD5, md5pword, string, strlen (string));
-
-        for (j = 0; j < 16; j++) {
-                char a[3];
-                sprintf (a, "%02x", md5pword[j]);
-                md5_response[2*j] = a[0];
-                md5_response[2*j+1] = a[1];
-        }
-
-        return (g_strdup (md5_response));
+        return g_uri_escape_string (keyword, NULL, FALSE);
 }
 
 #define DRAG_SIZE 70
