@@ -18,8 +18,8 @@
  */
 
 #include "servers/ario-server.h"
-#include "glib/gslist.h"
-#include "gdk/gdkpixbuf.h"
+#include <glib.h>
+#include <gdk/gdk.h>
 
 /* Number of covers used to generate the drag & drop image */
 #define MAX_COVERS_IN_DRAG 3
@@ -82,27 +82,10 @@ void                    ario_util_format_track_buf           (const gchar *track
  */
 gchar*                  ario_util_format_title               (ArioServerSong *server_song);
 
-/**
- * Add an icon to the default icon factory
- *
- * @param stock_id The id of the icon to add
- * @param filename The icon filename
- */
-void                    ario_util_add_stock_icons            (const char *stock_id,
-                                                              const char *filename);
 /**
  * Initialise default icon factory with a few icons
  */
-void                    ario_util_init_stock_icons           (void);
-
-/**
- * Check if an icon is already present
- *
- * @param stock_id The id of the icon to check
- *
- * @return True if the icon is present, FALSE otherwise
- */
-gboolean                ario_util_has_stock_icons            (const char *stock_id);
+void                    ario_util_init_icons                 (void);
 
 /**
  * Get the path of Ario configuration
@@ -193,15 +176,6 @@ char *                  ario_util_format_keyword             (const char *keywor
  */
 char *                  ario_util_format_keyword_for_lastfm  (const char *keyword) G_GNUC_MALLOC;
 
-/**
- * Compute the MD5 hash of a string
- *
- * @param string The string to use for MD5 computation
- *
- * @return A newly allocated hash
- */
-gchar *                 ario_util_md5                        (const char *string) G_GNUC_MALLOC;
-
 /**
  * Generate an icon to use for Drag & Drop from a list of albums
  *
