@@ -19,8 +19,7 @@
 
 #include "covers/ario-cover.h"
 #include <glib.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 #include <string.h>
 #include <glib/gi18n.h>
 #include "ario-util.h"
@@ -101,7 +100,7 @@ gboolean
 ario_cover_size_is_valid (const int size)
 {
         ARIO_LOG_FUNCTION_START;
-        /* return true if the cover isn't too big or too small (blank amazon image) */
+        /* return true if the cover isn't too big or too small (blank image) */
         return (size < 1024 * 1024 * 10 && size > 900);
 }
 
