@@ -704,6 +704,7 @@ mpd_Status * mpd_getStatus(mpd_Connection * connection) {
 	status->volume = -1;
 	status->repeat = 0;
 	status->random = 0;
+	status->consume = 0;
 	status->playlist = -1;
 	status->playlistLength = -1;
 	status->state = -1;
@@ -734,6 +735,9 @@ mpd_Status * mpd_getStatus(mpd_Connection * connection) {
 		else if(strcmp(re->name,"random")==0) {
 			status->random = atoi(re->value);
 		}
+		else if(strcmp(re->name,"consume")==0) {
+			status->consume = atoi(re->value);
+		}
 		else if(strcmp(re->name,"playlist")==0) {
 			status->playlist = strtol(re->value,NULL,10);
 		}
@@ -1610,6 +1614,14 @@ void mpd_sendRandomCommand(mpd_Connection * connection, int randomMode) {
 	free(string);
 }
 
+void mpd_sendConsumeCommand(mpd_Connection * connection, int consumeMode) {
+	int len = strlen("consume")+2+INTLEN+3;
+	char *string = malloc(len);
+	snprintf(string, len, "consume \"%i\"\n", consumeMode);
+	mpd_executeCommand(connection,string);
+	free(string);
+}
+
 void mpd_sendSetvolCommand(mpd_Connection * connection, int volumeChange) {
 	int len = strlen("setvol")+2+INTLEN+3;
 	char *string = malloc(len);
