@@ -53,8 +53,6 @@ struct _ArioPluginManagerPrivate
         GtkWidget* configure_button;
 
         GtkWidget* about;
-
-        GtkWidget* popup_menu;
 };
 
 static ArioPluginInfo *plugin_manager_get_selected_plugin (ArioPluginManager *pm);
@@ -62,7 +60,7 @@ static void plugin_manager_toggle_active (ArioPluginManager *pm, GtkTreeIter *it
 static void ario_plugin_manager_finalize (GObject *object);
 
 #define ARIO_PLUGIN_MANAGER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), ARIO_TYPE_PLUGIN_MANAGER, ArioPluginManagerPrivate))
-G_DEFINE_TYPE (ArioPluginManager, ario_plugin_manager, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (ArioPluginManager, ario_plugin_manager, GTK_TYPE_BOX)
 
 static void
 ario_plugin_manager_class_init (ArioPluginManagerClass *klass)
@@ -98,8 +96,9 @@ about_button_cb (GtkWidget* button,
                                         "logo", pb,
                                         NULL);
 
-        pb = gtk_widget_render_icon (pm->priv->about, ario_plugin_info_get_icon_name (info),
-                                     -1, NULL);
+        pb = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+                                       ario_plugin_info_get_icon_name (info),
+                                       -1, 0, NULL);
         if (pb) {
                 gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (pm->priv->about), pb);
                 g_object_unref (pb);
@@ -189,7 +188,7 @@ plugin_manager_view_icon_cell_cb (GtkTreeViewColumn *tree_column,
                 return;
 
         g_object_set (G_OBJECT (cell),
-                      "stock-id", ario_plugin_info_get_icon_name (info),
+                      "icon-name", ario_plugin_info_get_icon_name (info),
                       "sensitive", ario_plugin_info_is_available (info),
                       NULL);
 }
@@ -209,9 +208,7 @@ active_toggled_cb (GtkCellRendererToggle *cell,
         model = gtk_tree_view_get_model (GTK_TREE_VIEW (pm->priv->tree));
         g_return_if_fail (model != NULL);
 
-        gtk_tree_model_get_iter (model, &iter, path);
-
-        if (&iter != NULL)
+        if (gtk_tree_model_get_iter (model, &iter, path))
                 plugin_manager_toggle_active (pm, &iter, model);
 
         gtk_tree_path_free (path);
@@ -247,9 +244,7 @@ row_activated_cb (GtkTreeView       *tree_view,
 
         g_return_if_fail (model != NULL);
 
-        gtk_tree_model_get_iter (model, &iter, path);
-
-        g_return_if_fail (&iter != NULL);
+        g_return_if_fail (gtk_tree_model_get_iter (model, &iter, path));
 
         plugin_manager_toggle_active (pm, &iter, model);
 }
@@ -374,25 +369,6 @@ plugin_manager_get_selected_plugin (ArioPluginManager *pm)
         return info;
 }
 
-static void
-plugin_manager_set_active_all (ArioPluginManager *pm,
-                               gboolean active)
-{
-        GtkTreeModel *model;
-        GtkTreeIter iter;
-
-        model = gtk_tree_view_get_model (GTK_TREE_VIEW (pm->priv->tree));
-
-        g_return_if_fail (model != NULL);
-
-        gtk_tree_model_get_iter_first (model, &iter);
-
-        do {
-                plugin_manager_set_active (pm, &iter, model, active);
-        }
-        while (gtk_tree_model_iter_next (model, &iter));
-}
-
 /* Callback used as the interactive search comparison function */
 static gboolean
 name_search_cb (GtkTreeModel *model,
@@ -433,168 +409,6 @@ name_search_cb (GtkTreeModel *model,
         return retval;
 }
 
-static void
-enable_plugin_menu_cb (GtkCheckMenuItem *checkmenuitem,
-                       ArioPluginManager *pm)
-{
-        GtkTreeModel *model;
-        GtkTreeIter iter;
-        GtkTreeSelection *selection;
-
-        model = gtk_tree_view_get_model (GTK_TREE_VIEW (pm->priv->tree));
-        g_return_if_fail (model != NULL);
-
-        selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pm->priv->tree));
-        g_return_if_fail (selection != NULL);
-
-        if (gtk_tree_selection_get_selected (selection, NULL, &iter))
-                plugin_manager_toggle_active (pm, &iter, model);
-}
-
-static void
-enable_all_menu_cb (GtkMenu *menu,
-                    ArioPluginManager *pm)
-{
-        plugin_manager_set_active_all (pm, TRUE);
-}
-
-static void
-disable_all_menu_cb (GtkMenu *menu,
-                     ArioPluginManager *pm)
-{
-        plugin_manager_set_active_all (pm, FALSE);
-}
-
-static GtkWidget *
-create_tree_popup_menu (ArioPluginManager *pm)
-{
-        GtkWidget *menu;
-        GtkWidget *item;
-        GtkWidget *image;
-        ArioPluginInfo *info;
-
-        info = plugin_manager_get_selected_plugin (pm);
-
-        menu = gtk_menu_new ();
-
-        item = gtk_image_menu_item_new_with_mnemonic (_("_About"));
-        image = gtk_image_new_from_stock (GTK_STOCK_ABOUT,
-                                          GTK_ICON_SIZE_MENU);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-        g_signal_connect (item, "activate",
-                          G_CALLBACK (about_button_cb), pm);
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        item = gtk_image_menu_item_new_with_mnemonic (_("C_onfigure"));
-        image = gtk_image_new_from_stock (GTK_STOCK_PREFERENCES,
-                                          GTK_ICON_SIZE_MENU);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-        g_signal_connect (item, "activate",
-                          G_CALLBACK (configure_button_cb), pm);
-        gtk_widget_set_sensitive (item, ario_plugin_info_is_configurable (info));
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        item = gtk_check_menu_item_new_with_mnemonic (_("A_ctivate"));
-        gtk_widget_set_sensitive (item, ario_plugin_info_is_available (info));
-        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-                                        ario_plugin_info_is_active (info));
-        g_signal_connect (item, "toggled",
-                          G_CALLBACK (enable_plugin_menu_cb), pm);
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        item = gtk_separator_menu_item_new ();
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        item = gtk_menu_item_new_with_mnemonic (_("Ac_tivate All"));
-        g_signal_connect (item, "activate",
-                          G_CALLBACK (enable_all_menu_cb), pm);
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        item = gtk_menu_item_new_with_mnemonic (_("_Deactivate All"));
-        g_signal_connect (item, "activate",
-                          G_CALLBACK (disable_all_menu_cb), pm);
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-        gtk_widget_show_all (menu);
-
-        return menu;
-}
-
-static void
-tree_popup_menu_detach (ArioPluginManager *pm,
-                        GtkMenu *menu)
-{
-        pm->priv->popup_menu = NULL;
-}
-
-static void
-show_tree_popup_menu (GtkTreeView *tree,
-                      ArioPluginManager *pm,
-                      GdkEventButton *event)
-{
-        if (pm->priv->popup_menu)
-                gtk_widget_destroy (pm->priv->popup_menu);
-
-        pm->priv->popup_menu = create_tree_popup_menu (pm);
-
-        gtk_menu_attach_to_widget (GTK_MENU (pm->priv->popup_menu),
-                                   GTK_WIDGET (pm),
-                                   (GtkMenuDetachFunc) tree_popup_menu_detach);
-
-        if (event != NULL) {
-                gtk_menu_popup (GTK_MENU (pm->priv->popup_menu), NULL, NULL,
-                                NULL, NULL,
-                                event->button, event->time);
-        } else {
-                gtk_menu_popup (GTK_MENU (pm->priv->popup_menu), NULL, NULL,
-                                NULL, tree,
-                                0, gtk_get_current_event_time ());
-
-                gtk_menu_shell_select_first (GTK_MENU_SHELL (pm->priv->popup_menu),
-                                             FALSE);
-        }
-}
-
-static gboolean
-button_press_event_cb (GtkWidget *tree,
-                       GdkEventButton *event,
-                       ArioPluginManager *pm)
-{
-        /* We want the treeview selection to be updated before showing the menu.
-         * This code is evil, thanks to Federico Mena Quintero's black magic.
-         * See: http://mail.gnome.org/archives/gtk-devel-list/2006-February/msg00168.html
-         * FIXME: Let's remove it asap.
-         */
-
-        static gboolean in_press = FALSE;
-        gboolean handled;
-
-        if (in_press)
-                return FALSE; /* we re-entered */
-
-        if (GDK_BUTTON_PRESS != event->type || 3 != event->button)
-                return FALSE; /* let the normal handler run */
-
-        in_press = TRUE;
-        handled = gtk_widget_event (tree, (GdkEvent *) event);
-        in_press = FALSE;
-
-        if (!handled)
-                return FALSE;
-
-        /* The selection is fully updated by now */
-        show_tree_popup_menu (GTK_TREE_VIEW (tree), pm, event);
-        return TRUE;
-}
-
-static gboolean
-popup_menu_cb (GtkTreeView *tree,
-               ArioPluginManager *pm)
-{
-        show_tree_popup_menu (tree, pm, NULL);
-        return TRUE;
-}
-
 static gint
 model_name_sort_func (GtkTreeModel *model,
                       GtkTreeIter  *iter1,
@@ -623,7 +437,6 @@ plugin_manager_construct_tree (ArioPluginManager *pm)
                                  GTK_TREE_MODEL (model));
         g_object_unref (model);
 
-        gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (pm->priv->tree), TRUE);
         gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (pm->priv->tree), FALSE);
 
         /* first column */
@@ -693,14 +506,6 @@ plugin_manager_construct_tree (ArioPluginManager *pm)
                           G_CALLBACK (row_activated_cb),
                           pm);
 
-        g_signal_connect (pm->priv->tree,
-                          "button-press-event",
-                          G_CALLBACK (button_press_event_cb),
-                          pm);
-        g_signal_connect (pm->priv->tree,
-                          "popup-menu",
-                          G_CALLBACK (popup_menu_cb),
-                          pm);
         gtk_widget_show (pm->priv->tree);
 }
 
@@ -708,13 +513,13 @@ static void
 ario_plugin_manager_init (ArioPluginManager *pm)
 {
         GtkWidget *label;
-        GtkWidget *alignment;
         GtkWidget *viewport;
         GtkWidget *hbuttonbox;
         gchar *markup;
 
         pm->priv = ARIO_PLUGIN_MANAGER_GET_PRIVATE (pm);
 
+        gtk_orientable_set_orientation (GTK_ORIENTABLE (pm), GTK_ORIENTATION_VERTICAL);
         gtk_box_set_spacing (GTK_BOX (pm), 6);
 
         label = gtk_label_new (NULL);
@@ -723,14 +528,9 @@ ario_plugin_manager_init (ArioPluginManager *pm)
         gtk_label_set_markup (GTK_LABEL (label), markup);
         g_free (markup);
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
         gtk_box_pack_start (GTK_BOX (pm), label, FALSE, TRUE, 0);
 
-        alignment = gtk_alignment_new (0., 0., 1., 1.);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-        gtk_box_pack_start (GTK_BOX (pm), alignment, TRUE, TRUE, 0);
-
         viewport = gtk_scrolled_window_new (NULL, NULL);
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (viewport),
                                         GTK_POLICY_AUTOMATIC,
@@ -738,24 +538,24 @@ ario_plugin_manager_init (ArioPluginManager *pm)
         gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (viewport),
                                              GTK_SHADOW_IN);
 
-        gtk_container_add (GTK_CONTAINER (alignment), viewport);
 
         pm->priv->tree = gtk_tree_view_new ();
         gtk_container_add (GTK_CONTAINER (viewport), pm->priv->tree);
+        gtk_box_pack_start (GTK_BOX (pm), viewport, TRUE, TRUE, 0);
 
-        hbuttonbox = gtk_hbutton_box_new ();
+        hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
         gtk_box_pack_start (GTK_BOX (pm), hbuttonbox, FALSE, FALSE, 0);
         gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
         gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-        pm->priv->about_button = gtk_button_new_from_stock (GTK_STOCK_ABOUT);
+        pm->priv->about_button = gtk_button_new_with_label (_("About"));
         gtk_container_add (GTK_CONTAINER (hbuttonbox), pm->priv->about_button);
 
-        pm->priv->configure_button = gtk_button_new_from_stock (GTK_STOCK_PREFERENCES);
+        pm->priv->configure_button = gtk_button_new_with_label (_("Preferences"));
         gtk_container_add (GTK_CONTAINER (hbuttonbox), pm->priv->configure_button);
 
         /* setup a window of a sane size. */
-        gtk_widget_set_size_request (GTK_WIDGET (viewport), 270, 100);
+        gtk_widget_set_size_request (GTK_WIDGET (viewport), 270, 300);
 
         g_signal_connect (pm->priv->about_button,
                           "clicked",
@@ -779,11 +579,6 @@ ario_plugin_manager_init (ArioPluginManager *pm)
 static void
 ario_plugin_manager_finalize (GObject *object)
 {
-        ArioPluginManager *pm = ARIO_PLUGIN_MANAGER (object);
-
-        if (pm->priv->popup_menu)
-                gtk_widget_destroy (pm->priv->popup_menu);
-
         G_OBJECT_CLASS (ario_plugin_manager_parent_class)->finalize (object);
 }
 
