@@ -61,7 +61,7 @@ struct ArioOthersPreferencesPrivate
 };
 
 #define ARIO_OTHERS_PREFERENCES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ARIO_OTHERS_PREFERENCES, ArioOthersPreferencesPrivate))
-G_DEFINE_TYPE (ArioOthersPreferences, ario_others_preferences, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (ArioOthersPreferences, ario_others_preferences, GTK_TYPE_BOX)
 
 static void
 ario_others_preferences_class_init (ArioOthersPreferencesClass *klass)
@@ -88,6 +88,8 @@ ario_others_preferences_new (void)
 
         g_return_val_if_fail (others_preferences->priv != NULL, NULL);
 
+        gtk_orientable_set_orientation (GTK_ORIENTABLE (others_preferences), GTK_ORIENTATION_VERTICAL);
+
         builder = gtk_builder_helpers_new (UI_PATH "others-prefs.ui",
                                            others_preferences);
 
@@ -110,14 +112,14 @@ ario_others_preferences_new (void)
         others_preferences->priv->in_radiobutton =
                 GTK_WIDGET (gtk_builder_get_object (builder, "pl_in_radiobutton"));
 
-        gtk_image_set_from_stock (GTK_IMAGE (gtk_builder_get_object (builder, "pl_below_image")),
-                                  "pl-below", GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_image_set_from_icon_name (GTK_IMAGE (gtk_builder_get_object (builder, "pl_below_image")),
+                                      "pl-below", GTK_ICON_SIZE_LARGE_TOOLBAR);
 
-        gtk_image_set_from_stock (GTK_IMAGE (gtk_builder_get_object (builder, "pl_right_image")),
-                                  "pl-right", GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_image_set_from_icon_name (GTK_IMAGE (gtk_builder_get_object (builder, "pl_right_image")),
+                                      "pl-right", GTK_ICON_SIZE_LARGE_TOOLBAR);
 
-        gtk_image_set_from_stock (GTK_IMAGE (gtk_builder_get_object (builder, "pl_in_image")),
-                                  "pl-inside", GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_image_set_from_icon_name (GTK_IMAGE (gtk_builder_get_object (builder, "pl_in_image")),
+                                      "pl-inside", GTK_ICON_SIZE_LARGE_TOOLBAR);
 
         gtk_builder_helpers_boldify_label (builder, "interface_label");
         gtk_builder_helpers_boldify_label (builder, "proxy_frame_label");
