@@ -29,6 +29,7 @@
 #include "ario-util.h"
 #include "preferences/ario-preferences.h"
 #include "lib/ario-conf.h"
+#include "lib/gtk-builder-helpers.h"
 #include "widgets/ario-playlist.h"
 
 /* Number of milliseconds in 1 second */
@@ -76,6 +77,7 @@ static void ario_mpd_do_pause (void);
 static void ario_mpd_do_stop (void);
 static void ario_mpd_set_current_elapsed (const gint elapsed);
 static void ario_mpd_set_current_volume (const gint volume);
+static void ario_mpd_set_current_consume (const gboolean consume);
 static void ario_mpd_set_current_random (const gboolean random);
 static void ario_mpd_set_current_repeat (const gboolean repeat);
 static void ario_mpd_set_crossfadetime (const int crossfadetime);
@@ -162,6 +164,7 @@ ario_mpd_class_init (ArioMpdClass *klass)
         server_class->do_stop = ario_mpd_do_stop;
         server_class->set_current_elapsed = ario_mpd_set_current_elapsed;
         server_class->set_current_volume = ario_mpd_set_current_volume;
+        server_class->set_current_consume = ario_mpd_set_current_consume;
         server_class->set_current_random = ario_mpd_set_current_random;
         server_class->set_current_repeat = ario_mpd_set_current_repeat;
         server_class->set_crossfadetime = ario_mpd_set_crossfadetime;
@@ -306,10 +309,16 @@ ario_mpd_update_elapsed (gpointer data)
         return TRUE;
 }
 
-static void
+static gboolean
 ario_mpd_emit_storedplaylist (gpointer not_used)
 {
         g_signal_emit_by_name (G_OBJECT (server_instance), "storedplaylists_changed");
+
+        /*
+         * We're being hooked into the main loop using g_idle_add and
+         * want to be called just once
+         */
+        return FALSE;
 }
 
 static void
@@ -507,32 +516,30 @@ static void
 ario_mpd_connect (void)
 {
         ARIO_LOG_FUNCTION_START;
-        GtkWidget *win = NULL, *vbox,*label, *bar;
+        GtkBuilder *builder;
+        GtkWidget *win = NULL;
+        static GtkProgressBar *bar;
         GThread* thread;
         GtkWidget *dialog;
         gboolean is_in_error = (instance->priv->reconnect_time > 0);
 
-        thread = g_thread_create ((GThreadFunc) ario_mpd_connect_thread,
-                                  instance, TRUE, NULL);
+        thread = g_thread_new ("connect",
+                               (GThreadFunc) ario_mpd_connect_thread,
+                               instance);
 
         if (!is_in_error) {
-                win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-                gtk_window_set_modal (GTK_WINDOW (win), TRUE);
-                vbox = gtk_vbox_new (FALSE, 0);
-                label = gtk_label_new (_("Connecting to server..."));
-                bar = gtk_progress_bar_new ();
+                builder = gtk_builder_new ();
+                gtk_builder_add_from_file (builder, UI_PATH "connection-dialog.ui", NULL);
 
-                gtk_container_add (GTK_CONTAINER (win), vbox);
-                gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 6);
-                gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 6);
+                win = GTK_WIDGET (gtk_builder_get_object (builder, "ario_connection_dialog"));
+                bar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "connection_progressbar"));
+
+                g_object_unref (builder);
 
-                gtk_window_set_resizable (GTK_WINDOW (win), FALSE);
-                gtk_window_set_title (GTK_WINDOW (win), "Ario");
-                gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_CENTER);
                 gtk_widget_show_all (win);
 
                 while (instance->parent.connecting) {
-                        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (bar));
+                        gtk_progress_bar_pulse (bar);
                         while (gtk_events_pending ())
                                 gtk_main_iteration ();
                         g_usleep (200000);
@@ -569,6 +576,20 @@ ario_mpd_disconnect (void)
 
         if (instance->priv->support_idle)
                 ario_mpd_idle_free ();
+
+        /*
+         * check if there is a connection again
+         *
+         * if the connection has been cut, a call to ario_mpd_idle_free
+         * might time out and cause ario_mpd_disconnect to be called a
+         * second time and free the connection and set the pointer
+         * to NULL, causing the first invocation of this function
+         * to segfault. Since the second invocation cleaned everything
+         * up, we can just return.
+         */
+        if (!instance->priv->connection)
+                return;
+
         mpd_connection_free (instance->priv->connection);
         instance->priv->connection = NULL;
 
@@ -1045,6 +1066,9 @@ ario_mpd_update_status (void)
                                 instance->parent.playlist_length = mpd_status_get_queue_length (instance->priv->status);
                         }
 
+                        if (instance->parent.consume != mpd_status_get_consume (instance->priv->status))
+                                g_object_set (G_OBJECT (instance), "consume", mpd_status_get_consume (instance->priv->status), NULL);
+
                         if (instance->parent.random != mpd_status_get_random (instance->priv->status))
                                 g_object_set (G_OBJECT (instance), "random", mpd_status_get_random (instance->priv->status), NULL);
 
@@ -1209,6 +1233,18 @@ ario_mpd_set_current_volume (const gint volume)
         ario_mpd_update_status ();
 }
 
+static void
+ario_mpd_set_current_consume (const gboolean consume)
+{
+        ARIO_LOG_FUNCTION_START;
+        if (ario_mpd_command_preinvoke ())
+                return;
+
+        mpd_run_consume (instance->priv->connection, consume);
+
+        ario_mpd_command_postinvoke ();
+}
+
 static void
 ario_mpd_set_current_random (const gboolean random)
 {
