@@ -21,7 +21,7 @@
 #define __ARIO_SHELL_COVERDOWNLOADER_H
 
 #include <glib.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
