@@ -22,7 +22,7 @@
 #define __ARIO_SHELL_COVERSELECT_H
 
 #include <glib.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 #include "servers/ario-server.h"
 
 G_BEGIN_DECLS
