@@ -20,7 +20,7 @@
 #ifndef __ARIO_SHELL_H
 #define __ARIO_SHELL_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -41,14 +41,14 @@ typedef struct ArioShellPrivate ArioShellPrivate;
 
 typedef struct
 {
-        GtkWindow parent;
+        GtkApplicationWindow parent;
 
         ArioShellPrivate *priv;
 } ArioShell;
 
 typedef struct
 {
-        GtkWindowClass parent_class;
+        GtkApplicationWindowClass parent_class;
 } ArioShellClass;
 
 /* Main Window visibility */
@@ -61,7 +61,7 @@ typedef enum
 
 GType           ario_shell_get_type             (void) G_GNUC_CONST;
 
-ArioShell *     ario_shell_new                  (void);
+ArioShell *     ario_shell_new                  (GtkApplication *app);
 
 void            ario_shell_construct            (ArioShell *shell,
                                                  gboolean minimized);
