@@ -20,7 +20,7 @@
 #ifndef __ARIO_BROWSER_H
 #define __ARIO_BROWSER_H
 
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 #include "sources/ario-source.h"
 
 #define MAX_TREE_NB 5
@@ -55,8 +55,7 @@ typedef struct
 
 GType                   ario_browser_get_type   (void) G_GNUC_CONST;
 
-GtkWidget*              ario_browser_new        (GtkUIManager *mgr,
-                                                 GtkActionGroup *group);
+GtkWidget*              ario_browser_new        (void);
 
 G_END_DECLS
 
