@@ -20,7 +20,7 @@
 #ifndef __ARIO_SEARCH_H
 #define __ARIO_SEARCH_H
 
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 #include <config.h>
 #include "sources/ario-source.h"
 
@@ -56,8 +56,7 @@ typedef struct
 
 GType                   ario_search_get_type   (void) G_GNUC_CONST;
 
-GtkWidget*              ario_search_new        (GtkUIManager *mgr,
-                                                GtkActionGroup *group);
+GtkWidget*              ario_search_new        (void);
 
 G_END_DECLS
 
