@@ -45,10 +45,8 @@ static gboolean ario_source_manager_switch_page_cb (GtkNotebook *notebook,
 struct ArioSourceManagerPrivate
 {
         GSList *sources;
-        GtkUIManager *ui_manager;
 
         ArioSource *source;
-        GtkActionGroup *group;
 };
 
 static ArioSourceManager *instance = NULL;
@@ -56,7 +54,6 @@ static ArioSourceManager *instance = NULL;
 typedef struct ArioSourceData
 {
         ArioSource *source;
-        guint ui_merge_id;
 } ArioSourceData;
 
 #define ARIO_SOURCE_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ARIO_TYPE_SOURCE_MANAGER, ArioSourceManagerPrivate))
@@ -78,8 +75,7 @@ ario_source_manager_init (ArioSourceManager *sourcemanager)
 }
 
 GtkWidget *
-ario_source_manager_get_instance (GtkUIManager *mgr,
-                                 GtkActionGroup *group)
+ario_source_manager_get_instance (void)
 {
         ARIO_LOG_FUNCTION_START;
         GtkWidget *source;
@@ -92,24 +88,18 @@ ario_source_manager_get_instance (GtkUIManager *mgr,
                                  NULL);
         g_return_val_if_fail (instance->priv != NULL, NULL);
 
-        instance->priv->ui_manager = mgr;
-        instance->priv->group = group;
-
         /* Create browser */
-        source = ario_browser_new (mgr,
-                                   group);
+        source = ario_browser_new ();
         ario_source_manager_append (ARIO_SOURCE (source));
 
 #ifdef ENABLE_SEARCH
         /* Create search */
-        source = ario_search_new (mgr,
-                                  group);
+        source = ario_search_new ();
         ario_source_manager_append (ARIO_SOURCE (source));
 #endif  /* ENABLE_SEARCH */
 #ifdef ENABLE_STOREDPLAYLISTS
         /* Create stored playlists source */
-        source = ario_storedplaylists_new (mgr,
-                                           group);
+        source = ario_storedplaylists_new ();
         ario_source_manager_append (ARIO_SOURCE (source));
 #endif  /* ENABLE_STOREDPLAYLISTS */
 
@@ -141,7 +131,7 @@ ario_source_manager_get_instance (GtkUIManager *mgr,
 
 static void
 ario_source_manager_shutdown_foreach (ArioSource *source,
-                                     GSList **ordered_sources)
+                                      GSList **ordered_sources)
 {
         ARIO_LOG_FUNCTION_START;
         /* Shutdown source */
@@ -225,7 +215,7 @@ ario_source_manager_sync (ArioSourceManager *sourcemanager)
 
 static void
 ario_source_manager_showtabs_changed_cb (guint notification_id,
-                                        ArioSourceManager *sourcemanager)
+                                         ArioSourceManager *sourcemanager)
 {
         ARIO_LOG_FUNCTION_START;
         /* Set tabs visibility */
@@ -235,11 +225,10 @@ ario_source_manager_showtabs_changed_cb (guint notification_id,
 
 static void
 ario_source_manager_set_source_active (ArioSource *source,
-                                      gboolean active)
+                                       gboolean active)
 {
         ARIO_LOG_FUNCTION_START;
         gchar *conf_name;
-        GtkAction *action;
 
         /* Set source activity in preferences */
         conf_name = g_strconcat (ario_source_get_id (source), "-active", NULL);
@@ -255,24 +244,11 @@ ario_source_manager_set_source_active (ArioSource *source,
                 /* Hide source */
                 gtk_widget_hide (GTK_WIDGET (source));
         }
-
-        /* Select source in menu */
-        action = gtk_action_group_get_action (instance->priv->group, ario_source_get_id (source));
-        gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), active);
-}
-
-static void
-ario_source_manager_menu_source_cb (GtkToggleAction *action,
-                                   ArioSource *source)
-{
-        ARIO_LOG_FUNCTION_START;
-        /* Select source as in menu */
-        ario_source_manager_set_source_active (source, gtk_toggle_action_get_active (action));
 }
 
 static void
 ario_source_manager_menu_cb (GtkCheckMenuItem *checkmenuitem,
-                            ArioSource *source)
+                             ArioSource *source)
 {
         ARIO_LOG_FUNCTION_START;
         /* Select source as in menu */
@@ -286,17 +262,16 @@ ario_source_manager_append (ArioSource *source)
         GtkWidget *hbox;
         gchar *conf_name;
         ArioSourceData *data;
-        guint ui_merge_id;
 
         /* Create hbox for tab header */
-        hbox = gtk_hbox_new (FALSE, 4);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 
         /* Add source icon to hbox */
         gtk_box_pack_start (GTK_BOX (hbox),
-                            gtk_image_new_from_stock (ario_source_get_icon (source), GTK_ICON_SIZE_MENU),
+                            gtk_image_new_from_icon_name (ario_source_get_icon (source), GTK_ICON_SIZE_MENU),
                             TRUE, TRUE, 0);
 
-        /* Add source nqme to hbox */
+        /* Add source name to hbox */
         gtk_box_pack_start (GTK_BOX (hbox),
                             gtk_label_new (ario_source_get_name (source)),
                             TRUE, TRUE, 0);
@@ -318,32 +293,11 @@ ario_source_manager_append (ArioSource *source)
         else
                 gtk_widget_hide (GTK_WIDGET (source));
         gtk_widget_set_no_show_all (GTK_WIDGET (source), TRUE);
-
-        /* Add source in menu for selection */
-        ui_merge_id = gtk_ui_manager_new_merge_id (instance->priv->ui_manager);
-        gtk_ui_manager_add_ui (instance->priv->ui_manager,
-                               ui_merge_id,
-                               "/MenuBar/ViewMenu/ViewMenuSourcesPlaceholder",
-                               ario_source_get_id (source),
-                               ario_source_get_id (source),
-                               GTK_UI_MANAGER_MENUITEM,
-                               FALSE);
-
-        /* Add source to popup menu for selection */
-        GtkToggleActionEntry actions [] =
-        {
-                { ario_source_get_id (source), NULL, ario_source_get_name (source), NULL,
-                        NULL, G_CALLBACK (ario_source_manager_menu_source_cb), ario_conf_get_boolean (conf_name, TRUE) }
-        };
         g_free (conf_name);
-        gtk_action_group_add_toggle_actions (instance->priv->group,
-                                             actions, 1,
-                                             source);
 
         /* Add source data to list */
         data = (ArioSourceData *) g_malloc (sizeof (ArioSourceData));
         data->source = source;
-        data->ui_merge_id = ui_merge_id;
 
         instance->priv->sources = g_slist_append (instance->priv->sources, data);
 }
@@ -368,13 +322,6 @@ ario_source_manager_remove (ArioSource *source)
                 if (data->source == source) {
                         /* Remove the source from the list */
                         instance->priv->sources = g_slist_remove (instance->priv->sources, data);
-
-                        /* Remove the source from UI manager */
-                        gtk_ui_manager_remove_ui (instance->priv->ui_manager, data->ui_merge_id);
-
-                        /* Remove the source from popup menu */
-                        gtk_action_group_remove_action (instance->priv->group,
-                                                        gtk_action_group_get_action (instance->priv->group, ario_source_get_id (source)));
                         g_free (data);
                         break;
                 }
@@ -385,8 +332,8 @@ ario_source_manager_remove (ArioSource *source)
 
 static gboolean
 ario_source_manager_button_press_cb (GtkWidget *widget,
-                                    GdkEventButton *event,
-                                    ArioSourceManager *sourcemanager)
+                                     GdkEventButton *event,
+                                     ArioSourceManager *sourcemanager)
 {
         ARIO_LOG_FUNCTION_START;
         GtkWidget *menu;
@@ -417,8 +364,7 @@ ario_source_manager_button_press_cb (GtkWidget *widget,
 
                 /* Show popup menu */
                 gtk_widget_show_all (menu);
-                gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3,
-                                gtk_get_current_event_time ());
+                gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
         }
 
         return FALSE;
