@@ -20,7 +20,7 @@
 #include "sources/ario-source.h"
 #include <config.h>
 
-G_DEFINE_TYPE (ArioSource, ario_source, GTK_TYPE_HBOX)
+G_DEFINE_TYPE (ArioSource, ario_source, GTK_TYPE_BOX)
 
 static void
 dummy (ArioSource *source)
@@ -50,7 +50,7 @@ ario_source_class_init (ArioSourceClass *klass)
 static void
 ario_source_init (ArioSource *source)
 {
-        /* Empty */
+        gtk_orientable_set_orientation (GTK_ORIENTABLE (source), GTK_ORIENTATION_HORIZONTAL);
 }
 
 gchar *
