@@ -20,7 +20,7 @@
 #ifndef __ARIO_STOREDPLAYLISTS_H
 #define __ARIO_STOREDPLAYLISTS_H
 
-#include <gtk/gtkhpaned.h>
+#include <gtk/gtk.h>
 #include <config.h>
 #include "sources/ario-source.h"
 
@@ -55,8 +55,8 @@ typedef struct
 
 GType                   ario_storedplaylists_get_type   (void) G_GNUC_CONST;
 
-GtkWidget*              ario_storedplaylists_new        (GtkUIManager *mgr,
-                                                         GtkActionGroup *group);
+GtkWidget*              ario_storedplaylists_new        (void);
+
 G_END_DECLS
 
 #endif  /* ENABLE_STOREDPLAYLISTS */
