@@ -55,10 +55,13 @@ static void ario_header_cover_changed_cb (ArioCoverHandler *cover_handler,
 static void ario_header_elapsed_changed_cb (ArioServer *server,
                                             int elapsed,
                                             ArioHeader *header);
+static void ario_header_consume_changed_cb (ArioServer *server,
+                                           ArioHeader *header);
 static void ario_header_random_changed_cb (ArioServer *server,
                                            ArioHeader *header);
 static void ario_header_repeat_changed_cb (ArioServer *server,
                                            ArioHeader *header);
+static void ario_header_do_consume (ArioHeader *header);
 static void ario_header_do_random (ArioHeader *header);
 static void ario_header_do_repeat (ArioHeader *header);
 
@@ -69,6 +72,7 @@ struct ArioHeaderPrivate
 {
         GtkWidget *prev_button;
         GtkWidget *play_pause_button;
+        GtkWidget *consume_button;
         GtkWidget *random_button;
         GtkWidget *repeat_button;
 
@@ -99,7 +103,7 @@ struct ArioHeaderPrivate
 };
 
 #define ARIO_HEADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ARIO_HEADER, ArioHeaderPrivate))
-G_DEFINE_TYPE (ArioHeader, ario_header, GTK_TYPE_HBOX)
+G_DEFINE_TYPE (ArioHeader, ario_header, GTK_TYPE_BOX)
 
 static void
 ario_header_class_init (ArioHeaderClass *klass)
@@ -176,7 +180,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
         GtkTargetList *targets;
         GtkTargetEntry *target_entry;
         gint n_elem;
-        GtkWidget *image, *hbox, *right_hbox, *vbox, *alignment;
+        GtkWidget *image, *hbox, *right_hbox, *vbox;
         GList *focus = NULL;
 
         klass = ARIO_HEADER_CLASS (g_type_class_peek (TYPE_ARIO_HEADER));
@@ -184,9 +188,10 @@ ario_header_constructor (GType type, guint n_construct_properties,
         parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
         header = ARIO_HEADER (parent_class->constructor (type, n_construct_properties,
                                                          construct_properties));
+        gtk_orientable_set_orientation (GTK_ORIENTABLE (header), GTK_ORIENTATION_HORIZONTAL);
 
         /* Construct previous button */
-        image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PREVIOUS,
+        image = gtk_image_new_from_icon_name ("media-skip-backward",
                                           GTK_ICON_SIZE_LARGE_TOOLBAR);
 
         header->priv->prev_button = gtk_button_new ();
@@ -199,11 +204,11 @@ ario_header_constructor (GType type, guint n_construct_properties,
                                      _("Play previous song"));
 
         /* Construct button images */
-        header->priv->play_image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PLAY,
+        header->priv->play_image = gtk_image_new_from_icon_name ("media-playback-start",
                                                              GTK_ICON_SIZE_LARGE_TOOLBAR);
         g_object_ref (header->priv->play_image);
         gtk_widget_show (header->priv->play_image);
-        header->priv->pause_image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PAUSE,
+        header->priv->pause_image = gtk_image_new_from_icon_name ("media-playback-pause",
                                                               GTK_ICON_SIZE_LARGE_TOOLBAR);
         g_object_ref (header->priv->pause_image);
         gtk_widget_show (header->priv->pause_image);
@@ -217,7 +222,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
                                      _("Play/Pause the music"));
 
         /* Construct stop button */
-        image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_STOP,
+        image = gtk_image_new_from_icon_name ("media-playback-stop",
                                           GTK_ICON_SIZE_LARGE_TOOLBAR);
         header->priv->stop_button = gtk_button_new ();
         gtk_container_add (GTK_CONTAINER (header->priv->stop_button), image);
@@ -229,7 +234,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
                                      _("Stop the music"));
 
         /* Construct next button */
-        image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_NEXT,
+        image = gtk_image_new_from_icon_name ("media-skip-forward",
                                           GTK_ICON_SIZE_LARGE_TOOLBAR);
         header->priv->next_button = gtk_button_new ();
         gtk_container_add (GTK_CONTAINER (header->priv->next_button), image);
@@ -278,15 +283,13 @@ ario_header_constructor (GType type, guint n_construct_properties,
         header->priv->song = gtk_label_new ("");
         gtk_label_set_ellipsize (GTK_LABEL (header->priv->song), PANGO_ELLIPSIZE_END);
         gtk_label_set_use_markup (GTK_LABEL (header->priv->song), TRUE);
-        gtk_misc_set_alignment (GTK_MISC (header->priv->song), 0, 0);
 
         header->priv->artist_album = gtk_label_new ("");
         gtk_label_set_ellipsize (GTK_LABEL (header->priv->artist_album), PANGO_ELLIPSIZE_END);
-        gtk_misc_set_alignment (GTK_MISC (header->priv->artist_album), 0, 0);
 
         /* Construct time slider */
         header->priv->adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 10.0, 1.0, 10.0, 0.0));
-        header->priv->scale = gtk_hscale_new (header->priv->adjustment);
+        header->priv->scale = gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, header->priv->adjustment);
 
         g_signal_connect (header->priv->scale,
                           "button_press_event",
@@ -310,8 +313,20 @@ ario_header_constructor (GType type, guint n_construct_properties,
         header->priv->of = gtk_label_new (_(" of "));
         header->priv->total = gtk_label_new ("0:00");
 
+        /* Construct consume button */
+        image = gtk_image_new_from_icon_name ("consume",
+                                          GTK_ICON_SIZE_LARGE_TOOLBAR);
+        header->priv->consume_button = gtk_toggle_button_new ();
+        gtk_container_add (GTK_CONTAINER (header->priv->consume_button), image);
+        g_signal_connect_swapped (header->priv->consume_button,
+                                  "clicked",
+                                  G_CALLBACK (ario_header_do_consume),
+                                  header);
+        gtk_widget_set_tooltip_text (GTK_WIDGET (header->priv->consume_button),
+                                     _("Toggle 'consume' (remove played song from playlist) on/off"));
+
         /* Construct random button */
-        image = gtk_image_new_from_stock ("random",
+        image = gtk_image_new_from_icon_name ("shuffle",
                                           GTK_ICON_SIZE_LARGE_TOOLBAR);
         header->priv->random_button = gtk_toggle_button_new ();
         gtk_container_add (GTK_CONTAINER (header->priv->random_button), image);
@@ -323,7 +338,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
                                      _("Toggle random on/off"));
 
         /* Construct repeat button */
-        image = gtk_image_new_from_stock ("repeat",
+        image = gtk_image_new_from_icon_name ("repeat",
                                           GTK_ICON_SIZE_LARGE_TOOLBAR);
         header->priv->repeat_button = gtk_toggle_button_new ();
         gtk_container_add (GTK_CONTAINER (header->priv->repeat_button), image);
@@ -343,7 +358,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
         gtk_box_set_spacing (GTK_BOX (header), 12);
 
         /* Add command Buttons */
-        hbox = gtk_hbox_new (FALSE, 5);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
         gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 
         gtk_box_pack_start (GTK_BOX (hbox), header->priv->prev_button, FALSE, TRUE, 0);
@@ -351,26 +366,22 @@ ario_header_constructor (GType type, guint n_construct_properties,
         gtk_box_pack_start (GTK_BOX (hbox), header->priv->stop_button, FALSE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (hbox), header->priv->next_button, FALSE, TRUE, 0);
 
-        alignment = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
-        gtk_container_add (GTK_CONTAINER (alignment), hbox);
-        gtk_box_pack_start (GTK_BOX (header), alignment, FALSE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (header), hbox, FALSE, TRUE, 0);
 
         /* Add cover */
         gtk_box_pack_start (GTK_BOX (header), cover_event_box, FALSE, TRUE, 0);
 
         /* Add song labels */
-        vbox = gtk_vbox_new (FALSE, 0);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_box_pack_start (GTK_BOX (vbox), header->priv->song, TRUE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (vbox), header->priv->artist_album, TRUE, TRUE, 0);
 
-        alignment = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
-        gtk_container_add (GTK_CONTAINER (alignment), vbox);
-        gtk_box_pack_start (GTK_BOX (header), alignment, TRUE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (header), vbox, TRUE, TRUE, 0);
 
         /* Add time slider */
-        vbox = gtk_vbox_new (FALSE, 0);
-        hbox = gtk_hbox_new (FALSE, 0);
-        right_hbox = gtk_hbox_new (FALSE, 5);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+        right_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
 
         gtk_box_pack_start (GTK_BOX (hbox), header->priv->elapsed, FALSE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (hbox), header->priv->of, FALSE, TRUE, 0);
@@ -380,16 +391,15 @@ ario_header_constructor (GType type, guint n_construct_properties,
         gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (right_hbox), vbox, FALSE, TRUE, 0);
 
-        /* Add random/repeat buttons */
+        /* Add consume/random/repeat buttons */
+        gtk_box_pack_start (GTK_BOX (right_hbox), header->priv->consume_button, FALSE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (right_hbox), header->priv->random_button, FALSE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (right_hbox), header->priv->repeat_button, FALSE, TRUE, 0);
 
         /* Add volume button */
         gtk_box_pack_start (GTK_BOX (right_hbox), header->priv->volume_button, FALSE, TRUE, 5);
 
-        alignment = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
-        gtk_container_add (GTK_CONTAINER (alignment), right_hbox);
-        gtk_box_pack_end (GTK_BOX (header), alignment, FALSE, TRUE, 0);
+        gtk_box_pack_end (GTK_BOX (header), right_hbox, FALSE, TRUE, 0);
 
         /* Set focus chain */
         focus = g_list_append (focus, header->priv->scale);
@@ -423,6 +433,9 @@ ario_header_new (void)
         g_signal_connect_object (server,
                                  "elapsed_changed", G_CALLBACK (ario_header_elapsed_changed_cb),
                                  header, 0);
+        g_signal_connect_object (server,
+                                 "consume_changed", G_CALLBACK (ario_header_consume_changed_cb),
+                                 header, 0);
         g_signal_connect_object (server,
                                  "random_changed", G_CALLBACK (ario_header_random_changed_cb),
                                  header, 0);
@@ -629,6 +642,7 @@ ario_header_state_changed_cb (ArioServer *server,
                 gtk_widget_set_sensitive (header->priv->prev_button, FALSE);
                 gtk_widget_set_sensitive (header->priv->play_pause_button, FALSE);
 
+                gtk_widget_set_sensitive (header->priv->consume_button, FALSE);
                 gtk_widget_set_sensitive (header->priv->random_button, FALSE);
                 gtk_widget_set_sensitive (header->priv->repeat_button, FALSE);
 
@@ -643,6 +657,7 @@ ario_header_state_changed_cb (ArioServer *server,
                 gtk_widget_set_sensitive (header->priv->prev_button, TRUE);
                 gtk_widget_set_sensitive (header->priv->play_pause_button, TRUE);
 
+                gtk_widget_set_sensitive (header->priv->consume_button, TRUE);
                 gtk_widget_set_sensitive (header->priv->random_button, TRUE);
                 gtk_widget_set_sensitive (header->priv->repeat_button, TRUE);
 
@@ -674,6 +689,31 @@ ario_header_elapsed_changed_cb (ArioServer *server,
         gtk_adjustment_set_value (header->priv->adjustment, (gdouble) elapsed);
 }
 
+static void
+ario_header_consume_changed_cb (ArioServer *server,
+                               ArioHeader *header)
+{
+        ARIO_LOG_FUNCTION_START;
+        gboolean consume;
+
+        /* Get consume state on server */
+        consume = ario_server_get_current_consume ();
+
+        /* Block consume button signal */
+        g_signal_handlers_block_by_func (G_OBJECT (header->priv->consume_button),
+                                         G_CALLBACK (ario_header_do_consume),
+                                         header);
+
+        /* Change button state depending on consume value */
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (header->priv->consume_button),
+                                      consume);
+
+        /* Unblock consume button signal */
+        g_signal_handlers_unblock_by_func (G_OBJECT (header->priv->consume_button),
+                                           G_CALLBACK (ario_header_do_consume),
+                                           header);
+}
+
 static void
 ario_header_random_changed_cb (ArioServer *server,
                                ArioHeader *header)
@@ -834,6 +874,15 @@ ario_header_stop (ArioHeader *header)
         ario_server_do_stop ();
 }
 
+static void
+ario_header_do_consume (ArioHeader *header)
+{
+        ARIO_LOG_FUNCTION_START;
+        g_return_if_fail (IS_ARIO_HEADER (header));
+        /* Change consume on server */
+        ario_server_set_current_consume (!ario_server_get_current_consume ());
+}
+
 static void
 ario_header_do_random (ArioHeader *header)
 {
