@@ -20,7 +20,7 @@
 #ifndef __ARIO_HEADER_H
 #define __ARIO_HEADER_H
 
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -40,14 +40,14 @@ typedef struct ArioHeaderPrivate ArioHeaderPrivate;
  */
 typedef struct
 {
-        GtkHBox parent;
+        GtkBox parent;
 
         ArioHeaderPrivate *priv;
 } ArioHeader;
 
 typedef struct
 {
-        GtkHBoxClass parent;
+        GtkBoxClass parent;
 } ArioHeaderClass;
 
 GType           ario_header_get_type                 (void) G_GNUC_CONST;
