@@ -37,14 +37,6 @@
 typedef struct ArioPlaylistColumn ArioPlaylistColumn;
 
 static void ario_playlist_finalize (GObject *object);
-static void ario_playlist_set_property (GObject *object,
-                                        guint prop_id,
-                                        const GValue *value,
-                                        GParamSpec *pspec);
-static void ario_playlist_get_property (GObject *object,
-                                        guint prop_id,
-                                        GValue *value,
-                                        GParamSpec *pspec);
 static void ario_playlist_changed_cb (ArioServer *server,
                                       ArioPlaylist *playlist);
 static void ario_playlist_connectivity_changed_cb (ArioServer *server,
@@ -75,24 +67,32 @@ static gboolean ario_playlist_drag_drop_cb (GtkWidget * widget,
                                             gint x, gint y,
                                             guint time,
                                             ArioPlaylist *playlist);
-static void ario_playlist_cmd_clear (GtkAction *action,
-                                     ArioPlaylist *playlist);
-static void ario_playlist_cmd_shuffle (GtkAction *action,
-                                       ArioPlaylist *playlist);
-static void ario_playlist_cmd_remove (GtkAction *action,
-                                      ArioPlaylist *playlist);
-static void ario_playlist_cmd_crop (GtkAction *action,
-                                    ArioPlaylist *playlist);
+static void ario_playlist_cmd_clear (GSimpleAction *action,
+                                     GVariant *parameter,
+                                     gpointer data);
+static void ario_playlist_cmd_shuffle (GSimpleAction *action,
+                                       GVariant *parameter,
+                                       gpointer data);
+static void ario_playlist_cmd_remove (GSimpleAction *action,
+                                      GVariant *parameter,
+                                      gpointer data);
+static void ario_playlist_cmd_crop (GSimpleAction *action,
+                                    GVariant *parameter,
+                                    gpointer data);
 static void ario_playlist_search (ArioPlaylist *playlist,
                                   const char* text);
-static void ario_playlist_cmd_search (GtkAction *action,
-                                      ArioPlaylist *playlist);
-static void ario_playlist_cmd_songs_properties (GtkAction *action,
-                                                ArioPlaylist *playlist);
-static void ario_playlist_cmd_goto_playing_song (GtkAction *action,
-                                                 ArioPlaylist *playlist);
-static void ario_playlist_cmd_save (GtkAction *action,
-                                    ArioPlaylist *playlist);
+static void ario_playlist_cmd_search (GSimpleAction *action,
+                                      GVariant *parameter,
+                                      gpointer data);
+static void ario_playlist_cmd_songs_properties (GSimpleAction *action,
+                                                GVariant *parameter,
+                                                gpointer data);
+static void ario_playlist_cmd_goto_playing_song (GSimpleAction *action,
+                                                 GVariant *parameter,
+                                                 gpointer data);
+static void ario_playlist_cmd_save (GSimpleAction *action,
+                                    GVariant *parameter,
+                                    gpointer data);
 static gboolean ario_playlist_view_key_press_cb (GtkWidget *widget,
                                                  GdkEventKey *event,
                                                  ArioPlaylist *playlist);
@@ -125,44 +125,24 @@ struct ArioPlaylistPrivate
 
         GdkPixbuf *play_pixbuf;
 
-        GtkUIManager *ui_manager;
+        GtkWidget *menu;
 };
 
-static GtkActionEntry ario_playlist_actions [] =
-{
-        { "PlaylistClear", GTK_STOCK_CLEAR, N_("_Clear"), NULL,
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_clear) },
-        { "PlaylistShuffle", GTK_STOCK_REFRESH, N_("_Shuffle"), NULL,
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_shuffle) },
-        { "PlaylistCrop", GTK_STOCK_CUT, N_("Cr_op"), "<control>P",
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_crop) },
-        { "PlaylistSearch", GTK_STOCK_FIND, N_("_Search in playlist"), NULL,
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_search) },
-        { "PlaylistRemove", GTK_STOCK_REMOVE, N_("_Remove"), NULL,
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_remove) },
-        { "PlaylistSave", GTK_STOCK_SAVE, N_("_Save"), "<control>S",
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_save) },
-        { "PlaylistSongProperties", GTK_STOCK_PROPERTIES, N_("_Properties"), NULL,
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_songs_properties) },
-        { "PlaylistGotoPlaying", GTK_STOCK_JUMP_TO, N_("_Go to playing song"), "<control>L",
-                NULL,
-                G_CALLBACK (ario_playlist_cmd_goto_playing_song) }
+static const GActionEntry widget_actions[] = {
+        { "playlist-clear", ario_playlist_cmd_clear},
+        { "playlist-shuffle", ario_playlist_cmd_shuffle},
+        { "playlist-crop", ario_playlist_cmd_crop},
+        { "playlist-search", ario_playlist_cmd_search},
+        { "playlist-remove", ario_playlist_cmd_remove},
+        { "playlist-save", ario_playlist_cmd_save},
+        { "playlist-goto", ario_playlist_cmd_goto_playing_song},
+        { "playlist-properties", ario_playlist_cmd_songs_properties},
 };
 
-static guint ario_playlist_n_actions = G_N_ELEMENTS (ario_playlist_actions);
-
 /* Object properties */
 enum
 {
         PROP_0,
-        PROP_UI_MANAGER
 };
 
 /* Treeview columns */
@@ -240,6 +220,8 @@ static ArioPlaylistColumn all_columns []  = {
         { GENRE_COLUMN, PREF_GENRE_COLUMN_SIZE, PREF_GENRE_COLUMN_SIZE_DEFAULT, PREF_GENRE_COLUMN_ORDER, PREF_GENRE_COLUMN_ORDER_DEFAULT, PREF_GENRE_COLUMN_VISIBLE, PREF_GENRE_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
         { DATE_COLUMN, PREF_DATE_COLUMN_SIZE, PREF_DATE_COLUMN_SIZE_DEFAULT, PREF_DATE_COLUMN_ORDER, PREF_DATE_COLUMN_ORDER_DEFAULT, PREF_DATE_COLUMN_VISIBLE, PREF_DATE_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
         { DISC_COLUMN, PREF_DISC_COLUMN_SIZE, PREF_DISC_COLUMN_SIZE_DEFAULT, PREF_DISC_COLUMN_ORDER, PREF_DISC_COLUMN_ORDER_DEFAULT, PREF_DISC_COLUMN_VISIBLE, PREF_DISC_COLUMN_VISIBLE_DEFAULT, FALSE, TRUE, TRUE, NULL },
+        { -1, NULL, 0, NULL, 0, NULL, FALSE, FALSE, FALSE, FALSE, NULL },
+        { -1, NULL, 0, NULL, 0, NULL, FALSE, FALSE, FALSE, FALSE, NULL },
         { -1, NULL, 0, NULL, 0, NULL, FALSE, FALSE, FALSE, FALSE, NULL }
 };
 
@@ -275,7 +257,7 @@ ario_playlist_get_name (ArioSource *source)
 static gchar *
 ario_playlist_get_icon (ArioSource *source)
 {
-        return GTK_STOCK_INDEX;
+        return "";
 }
 
 static void
@@ -287,23 +269,12 @@ ario_playlist_class_init (ArioPlaylistClass *klass)
 
         /* Virtual methods */
         object_class->finalize = ario_playlist_finalize;
-        object_class->set_property = ario_playlist_set_property;
-        object_class->get_property = ario_playlist_get_property;
 
         /* Virtual ArioSource methods */
         source_class->get_id = ario_playlist_get_id;
         source_class->get_name = ario_playlist_get_name;
         source_class->get_icon = ario_playlist_get_icon;
 
-        /* Properties */
-        g_object_class_install_property (object_class,
-                                         PROP_UI_MANAGER,
-                                         g_param_spec_object ("ui-manager",
-                                                              "GtkUIManager",
-                                                              "GtkUIManager object",
-                                                              GTK_TYPE_UI_MANAGER,
-                                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-
         /* Private attributes */
         g_type_class_add_private (klass, sizeof (ArioPlaylistPrivate));
 }
@@ -525,7 +496,7 @@ ario_playlist_search_entry_key_press_cb (GtkWidget *widget,
 {
         ARIO_LOG_FUNCTION_START;
         /* Escape key closes the search box */
-        if (event->keyval == GDK_Escape) {
+        if (event->keyval == GDK_KEY_Escape) {
                 ario_playlist_search_close (NULL, playlist);
                 return TRUE;
         }
@@ -541,6 +512,8 @@ ario_playlist_init (ArioPlaylist *playlist)
         const gchar *column_names []  = { " ", _("Track"), _("Title"), _("Artist"), _("Album"), _("Duration"), _("File"), _("Genre"), _("Date"), _("Disc") };
         GtkWidget *image, *close_button, *vbox;
         GtkScrolledWindow *scrolled_window;
+        GtkBuilder *builder;
+        GMenuModel *menu;
 
         /* Attributes initialization */
         instance = playlist;
@@ -551,7 +524,7 @@ ario_playlist_init (ArioPlaylist *playlist)
         playlist->priv->play_pixbuf = gdk_pixbuf_new_from_file (PIXMAP_PATH "play.png", NULL);
 
         /* Create main vbox */
-        vbox = gtk_vbox_new (FALSE, 0);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
         /* Create scrolled window */
         scrolled_window = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
@@ -599,8 +572,6 @@ ario_playlist_init (ArioPlaylist *playlist)
         gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (playlist->priv->model),
                                                  ario_playlist_no_sort,
                                                  NULL, NULL);
-        gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (playlist->priv->tree),
-                                      TRUE);
         gtk_tree_view_set_enable_search (GTK_TREE_VIEW (playlist->priv->tree), FALSE);
         playlist->priv->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (playlist->priv->tree));
         gtk_tree_selection_set_mode (playlist->priv->selection,
@@ -620,6 +591,14 @@ ario_playlist_init (ArioPlaylist *playlist)
         /* Add the tree in the scrolled window */
         gtk_container_add (GTK_CONTAINER (scrolled_window), playlist->priv->tree);
 
+        /* Create menu */
+        builder = gtk_builder_new_from_file (UI_PATH "ario-playlist-menu.ui");
+        menu = G_MENU_MODEL (gtk_builder_get_object (builder, "menu"));
+        playlist->priv->menu = gtk_menu_new_from_model (menu);
+        gtk_menu_attach_to_widget  (GTK_MENU (playlist->priv->menu),
+                                    GTK_WIDGET (playlist),
+                                    NULL);
+
         /* Connect various signals of the tree */
         g_signal_connect (playlist->priv->tree,
                           "key_press_event",
@@ -647,10 +626,10 @@ ario_playlist_init (ArioPlaylist *playlist)
                           playlist);
 
         /* Creation of search box */
-        playlist->priv->search_hbox = gtk_hbox_new (FALSE, 6);
+        playlist->priv->search_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
-        image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-                                          GTK_ICON_SIZE_MENU);
+        image = gtk_image_new_from_icon_name ("window-close",
+                                              GTK_ICON_SIZE_MENU);
         close_button = gtk_button_new ();
         gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
         gtk_container_add (GTK_CONTAINER (close_button), image);
@@ -748,44 +727,6 @@ ario_playlist_finalize (GObject *object)
         G_OBJECT_CLASS (ario_playlist_parent_class)->finalize (object);
 }
 
-static void
-ario_playlist_set_property (GObject *object,
-                            guint prop_id,
-                            const GValue *value,
-                            GParamSpec *pspec)
-{
-        ARIO_LOG_FUNCTION_START;
-        ArioPlaylist *playlist = ARIO_PLAYLIST (object);
-
-        switch (prop_id) {
-        case PROP_UI_MANAGER:
-                playlist->priv->ui_manager = g_value_get_object (value);
-                break;
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-ario_playlist_get_property (GObject *object,
-                            guint prop_id,
-                            GValue *value,
-                            GParamSpec *pspec)
-{
-        ARIO_LOG_FUNCTION_START;
-        ArioPlaylist *playlist = ARIO_PLAYLIST (object);
-
-        switch (prop_id) {
-        case PROP_UI_MANAGER:
-                g_value_set_object (value, playlist->priv->ui_manager);
-                break;
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
 /**
  * This method removes the 'playing' pixbuf from the previous played
  * song and adds it to the new song
@@ -852,10 +793,9 @@ ario_playlist_changed_cb (ArioServer *server,
         gchar time[ARIO_MAX_TIME_SIZE];
         gchar *title;
         GSList *songs, *tmp;
-        ArioServerSong *song, *current_song;
+        ArioServerSong *song;
         gboolean need_set;
         GtkTreePath *path;
-        int state;
 
         /* Clear the playlist if ario is not connected to the server */
         if (!ario_server_is_connected ()) {
@@ -871,13 +811,6 @@ ario_playlist_changed_cb (ArioServer *server,
 
         old_length = playlist->priv->playlist_length;
 
-        /* Get current song */
-        state = ario_server_get_current_state ();
-        if (state == ARIO_STATE_UNKNOWN || state == ARIO_STATE_STOP)
-                current_song = NULL;
-        else
-                current_song = ario_server_get_current_song ();
-
         /* For each change in playlist */
         for (tmp = songs; tmp; tmp = g_slist_next (tmp)) {
                 song = tmp->data;
@@ -954,7 +887,7 @@ ario_playlist_song_changed_cb (ArioServer *server,
 
         /* Autoscroll in playlist on song chang if option is activated */
         if (ario_conf_get_boolean (PREF_PLAYLIST_AUTOSCROLL, PREF_PLAYLIST_AUTOSCROLL_DEFAULT))
-                ario_playlist_cmd_goto_playing_song (NULL, playlist);
+                ario_playlist_cmd_goto_playing_song (NULL, NULL, playlist);
 }
 
 static void
@@ -1049,8 +982,7 @@ ario_playlist_rows_reordered_cb (GtkTreeModel *tree_model,
 }
 
 GtkWidget *
-ario_playlist_new (GtkUIManager *mgr,
-                   GtkActionGroup *group)
+ario_playlist_new (void)
 {
         ARIO_LOG_FUNCTION_START;
         ArioServer *server = ario_server_get_instance ();
@@ -1058,7 +990,6 @@ ario_playlist_new (GtkUIManager *mgr,
         g_return_val_if_fail (instance == NULL, NULL);
 
         instance = g_object_new (TYPE_ARIO_PLAYLIST,
-                                 "ui-manager", mgr,
                                  NULL);
 
         g_return_val_if_fail (instance->priv != NULL, NULL);
@@ -1082,9 +1013,10 @@ ario_playlist_new (GtkUIManager *mgr,
                                  instance, 0);
 
         /* Add contextual menu actions */
-        gtk_action_group_add_actions (group,
-                                      ario_playlist_actions,
-                                      ario_playlist_n_actions, instance);
+        g_action_map_add_action_entries (G_ACTION_MAP (g_application_get_default ()),
+                                         widget_actions,
+                                         G_N_ELEMENTS (widget_actions),
+                                         instance);
 
         return GTK_WIDGET (instance);
 }
@@ -1334,14 +1266,13 @@ ario_playlist_drop_criterias (const int x, const int y,
         ArioServerAtomicCriteria *atomic_criteria;
         int i = 0, j;
         int nb;
-        GSList *filenames = NULL, *criterias = NULL;
+        GSList *criterias = NULL;
 
         /* Get a list of criteria from drag data */
         criterias_str = g_strsplit ((const gchar *) gtk_selection_data_get_data (data), "\n", 0);
         while (criterias_str[i] && *criterias_str[i] != '\0') {
                 nb = atoi (criterias_str[i]);
                 criteria = NULL;
-                filenames = NULL;
 
                 for (j=0; j<nb; ++j) {
                         atomic_criteria = (ArioServerAtomicCriteria *) g_malloc0 (sizeof (ArioServerAtomicCriteria));
@@ -1378,13 +1309,13 @@ ario_playlist_drag_leave_cb (GtkWidget *widget,
         /* Call the appropriate functions depending on data type */
         if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/internal-list", TRUE)) {
 #if GTK_CHECK_VERSION(2, 22, 0)
-                if (gdk_drag_context_get_actions (context) & GDK_ACTION_COPY)
+                if (gdk_drag_context_get_selected_action (context) & GDK_ACTION_COPY)
 #else
-                if (context->action & GDK_ACTION_COPY)
+                        if (context->action & GDK_ACTION_COPY)
 #endif
-                        ario_playlist_copy_rows (x, y);
-                else
-                        ario_playlist_move_rows (x, y);
+                                ario_playlist_copy_rows (x, y);
+                        else
+                                ario_playlist_move_rows (x, y);
         } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/songs-list", TRUE)) {
                 ario_playlist_drop_songs (x, y, data);
         } else if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/radios-list", TRUE)) {
@@ -1433,12 +1364,8 @@ ario_playlist_popup_menu_cb (ArioDndTree* tree,
                              ArioPlaylist *playlist)
 {
         ARIO_LOG_FUNCTION_START;
-        GtkWidget *menu;
-
         /* Show popup menu */
-        menu = gtk_ui_manager_get_widget (instance->priv->ui_manager, "/PlaylistPopup");
-        gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3,
-                        gtk_get_current_event_time ());
+        gtk_menu_popup_at_pointer (GTK_MENU (playlist->priv->menu), NULL);
 }
 
 static void
@@ -1450,8 +1377,9 @@ ario_playlist_activate_cb (ArioDndTree* tree,
 }
 
 static void
-ario_playlist_cmd_clear (GtkAction *action,
-                         ArioPlaylist *playlist)
+ario_playlist_cmd_clear (GSimpleAction *action,
+                         GVariant *parameter,
+                         gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
         /* Clear playlist */
@@ -1459,8 +1387,9 @@ ario_playlist_cmd_clear (GtkAction *action,
 }
 
 static void
-ario_playlist_cmd_shuffle (GtkAction *action,
-                           ArioPlaylist *playlist)
+ario_playlist_cmd_shuffle (GSimpleAction *action,
+                           GVariant *parameter,
+                           gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
         /* Shuffle playlist */
@@ -1502,8 +1431,9 @@ ario_playlist_remove (void)
 }
 
 static void
-ario_playlist_cmd_remove (GtkAction *action,
-                          ArioPlaylist *playlist)
+ario_playlist_cmd_remove (GSimpleAction *action,
+                          GVariant *parameter,
+                          gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
         ario_playlist_remove ();
@@ -1537,24 +1467,25 @@ ario_playlist_selection_crop_foreach (GtkTreeModel *model,
 }
 
 static void
-ario_playlist_cmd_crop (GtkAction *action,
-                        ArioPlaylist *playlist)
+ario_playlist_cmd_crop (GSimpleAction *action,
+                        GVariant *parameter,
+                        gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
-        ArioPlaylistCropData data;
+        ArioPlaylistCropData crop_data;
 
-        data.kept = 0;
-        data.deleted = 0;
+        crop_data.kept = 0;
+        crop_data.deleted = 0;
 
         /* Call ario_playlist_selection_crop_foreach, for each selected row */
         gtk_tree_selection_selected_foreach (instance->priv->selection,
                                              (GtkTreeSelectionForeachFunc) ario_playlist_selection_crop_foreach,
-                                             &data);
+                                             &crop_data);
 
         /* Delete all songs after the last selected one */
-        while (data.deleted + data.kept < instance->priv->playlist_length) {
-                ario_server_queue_delete_pos (data.kept);
-                ++data.deleted;
+        while (crop_data.deleted + crop_data.kept < instance->priv->playlist_length) {
+                ario_server_queue_delete_pos (crop_data.kept);
+                ++crop_data.deleted;
         }
 
         /* Commit song deletions */
@@ -1589,10 +1520,12 @@ ario_playlist_search (ArioPlaylist *playlist,
 }
 
 static void
-ario_playlist_cmd_search (GtkAction *action,
-                          ArioPlaylist *playlist)
+ario_playlist_cmd_search (GSimpleAction *action,
+                          GVariant *parameter,
+                          gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
+        ArioPlaylist *playlist = ARIO_PLAYLIST (data);
         ario_playlist_search (playlist, "");
         gtk_tree_model_filter_refilter (playlist->priv->filter);
 }
@@ -1613,10 +1546,12 @@ ario_playlist_selection_properties_foreach (GtkTreeModel *model,
 }
 
 static void
-ario_playlist_cmd_songs_properties (GtkAction *action,
-                                    ArioPlaylist *playlist)
+ario_playlist_cmd_songs_properties (GSimpleAction *action,
+                                    GVariant *parameter,
+                                    gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
+        ArioPlaylist *playlist = ARIO_PLAYLIST (data);
         GSList *paths = NULL;
         GtkWidget *songinfos;
 
@@ -1665,10 +1600,12 @@ ario_playlist_cmd_goto_playing_song_foreach (GtkTreeModel *model,
 }
 
 static void
-ario_playlist_cmd_goto_playing_song (GtkAction *action,
-                                     ArioPlaylist *playlist)
+ario_playlist_cmd_goto_playing_song (GSimpleAction *action,
+                                     GVariant *parameter,
+                                     gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
+        ArioPlaylist *playlist = ARIO_PLAYLIST (data);
 
         /* Call ario_playlist_cmd_goto_playing_song_foreach for each song in playlist */
         if (instance->priv->in_search) {
@@ -1686,8 +1623,9 @@ ario_playlist_cmd_goto_playing_song (GtkAction *action,
 }
 
 void
-ario_playlist_cmd_save (GtkAction *action,
-                        ArioPlaylist *playlist)
+ario_playlist_cmd_save (GSimpleAction *action,
+                        GVariant *parameter,
+                        gpointer data)
 {
         ARIO_LOG_FUNCTION_START;
         GtkWidget *dialog;
@@ -1700,16 +1638,16 @@ ario_playlist_cmd_save (GtkAction *action,
         dialog = gtk_dialog_new_with_buttons (_("Save playlist"),
                                               NULL,
                                               GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              GTK_STOCK_CANCEL,
+                                              _("_Cancel"),
                                               GTK_RESPONSE_CANCEL,
-                                              GTK_STOCK_OK,
+                                              _("_OK"),
                                               GTK_RESPONSE_OK,
                                               NULL);
         gtk_dialog_set_default_response (GTK_DIALOG (dialog),
                                          GTK_RESPONSE_OK);
         label = gtk_label_new (_("Playlist name :"));
         entry = gtk_entry_new ();
-        hbox = gtk_hbox_new (FALSE, 5);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
 
         gtk_box_pack_start (GTK_BOX (hbox),
                             label,
@@ -1762,16 +1700,16 @@ ario_playlist_view_key_press_cb (GtkWidget *widget,
 {
         ARIO_LOG_FUNCTION_START;
 
-        if (event->keyval == GDK_Delete) {
+        if (event->keyval == GDK_KEY_Delete) {
                 /* Del key removes songs from playlist */
                 ario_playlist_remove ();
-        } else if (event->keyval == GDK_Return) {
+        } else if (event->keyval == GDK_KEY_Return) {
                 /* Enter key activate a song */
                 ario_playlist_activate_selected ();
                 return TRUE;
         } else if (event->string
                    && event->length > 0
-                   && event->keyval != GDK_Escape
+                   && event->keyval != GDK_KEY_Escape
                    && !(event->state & GDK_CONTROL_MASK)) {
                 /* Other keys start the search in playlist */
                 ario_playlist_search (playlist, event->string);
